@@ -139,24 +139,22 @@ QVariantList AppEntry::actions() const
 {
     QVariantList actionList;
 
-    actionList << Kicker::recentDocumentActions(m_service);
-
-    if (actionList.count()) {
+    actionList << Kicker::jumpListActions(m_service);
+    if (!actionList.isEmpty()) {
         actionList << Kicker::createSeparatorActionItem();
     }
 
     QObject *appletInterface = m_owner->rootModel()->property("appletInterface").value<QObject *>();
 
-    if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Desktop)) {
-        actionList << Kicker::createActionItem(i18n("Add to Desktop"), "addToDesktop");
+    const QVariantList &addLauncherActions = Kicker::createAddLauncherActionList(appletInterface, m_service);
+    if (!addLauncherActions.isEmpty()) {
+        actionList << addLauncherActions
+                   << Kicker::createSeparatorActionItem();
     }
 
-    if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
-        actionList << Kicker::createActionItem(i18n("Add to Panel"), "addToPanel");
-    }
-
-    if (ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, m_service->entryPath())) {
-        actionList << Kicker::createActionItem(i18n("Add as Launcher"), "addToTaskManager");
+    const QVariantList &recentDocuments = Kicker::recentDocumentActions(m_service);
+    if (!recentDocuments.isEmpty()) {
+        actionList << recentDocuments << Kicker::createSeparatorActionItem();
     }
 
     if (m_menuEntryEditor->canEdit(m_service->entryPath())) {
@@ -220,12 +218,8 @@ bool AppEntry::run(const QString& actionId, const QVariant &argument)
 
     QObject *appletInterface = m_owner->rootModel()->property("appletInterface").value<QObject *>();
 
-    if (actionId == "addToDesktop" && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Desktop)) {
-        ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Desktop, m_service->entryPath());
-    } else if (actionId == "addToPanel" && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::Panel)) {
-        ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::Panel, m_service->entryPath());
-    } else if (actionId == "addToTaskManager" && ContainmentInterface::mayAddLauncher(appletInterface, ContainmentInterface::TaskManager, m_service->entryPath())) {
-        ContainmentInterface::addLauncher(appletInterface, ContainmentInterface::TaskManager, m_service->entryPath());
+    if (Kicker::handleAddLauncherAction(actionId, appletInterface, m_service)) {
+        return true;
     } else if (actionId == "editApplication" && m_menuEntryEditor->canEdit(m_service->entryPath())) {
         m_menuEntryEditor->edit(m_service->entryPath(), m_service->menuId());
 
@@ -240,6 +234,8 @@ bool AppEntry::run(const QString& actionId, const QVariant &argument)
                 return QProcess::startDetached(removeAppCmd.first(), removeAppCmd.mid(1) << argument.toString());
             }
         }
+    } else if (actionId == "_kicker_jumpListAction") {
+        return KRun::run(argument.toString(), {}, nullptr, m_service->name(), m_service->icon());
     }
 
     return Kicker::handleRecentDocumentAction(m_service, actionId, argument);
